# Based on the Fedora package - thanks!

# This package depends on automagic byte compilation
# https://fedoraproject.org/wiki/Changes/No_more_automagic_Python_bytecompilation_phase_2
%global _py_byte_compile 1
%global sphinxbuild sphinx-build-3
# Set the Python version for brp-python-bytecompile (see the Python guidelines).
# We also use this to set the PYTHON makefile variable.
%global __python %{__python3}

Name:           git-cola
Version:        4.0.4
Release:        %mkrel 3
Summary:        A sleek and powerful git GUI
Group:          Development/Tools
License:        GPLv2+
# Main site at https://git-cola.github.io, pypi page at:
URL:            https://pypi.org/project/git-cola/
Source0:        %pypi_source
BuildArch:      noarch

BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  xmlto-notex
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  rsync

BuildRequires:  python3-qt5-devel
BuildRequires:  python3-devel
BuildRequires:  python3-sphinx
BuildRequires:  python3-qtpy
# BuildRequires:  pkgconfig(pyside2)
BuildRequires:  python3dist(importlib-metadata)
# For %pyproject
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(setuptools-scm) 
BuildRequires:  python3dist(setuptools-scm[toml]) >= 3.4.1
#
# From requirements/requirements-dev.txt (for install-doc)
BuildRequires:  python3dist(jaraco.packaging)
BuildRequires:  python3dist(rst.linker) > 1.9
BuildRequires:  python3dist(sphinx-rtd-theme)

Requires:       python3-qt5
Requires:       python3-qt5-webengine
Requires:       python3-qtpy
# Requires:       python3-pyside2
Requires:       python3-pyinotify

Requires:       git
Requires:       hicolor-icon-theme

%description
git-cola is a powerful git GUI with a slick and intuitive user interface.


%prep
%autosetup -p1

# fix #!/usr/bin/env/python to #!/usr/bin/env/python3 everywhere
find . -type f -exec sh -c "head {} -n 1 | grep ^#\!\ \*/usr/bin/env\ python >/dev/null && sed -i -e sX^#\!\ \*/usr/bin/env\ python\ \*"\\\$"X#\!/usr/bin/env\ python3Xg {}" \;

%build
%global makeopts PYTHON="%{__python3}" %{?sphinxbuild:SPHINXBUILD="%{sphinxbuild}"} V=1
%pyproject_wheel
%make_build %{makeopts} doc


%install
%pyproject_install
%__make %{makeopts} DESTDIR=%{?buildroot} INSTALL="%{__install} -p" prefix=%{_prefix} install-doc install-html


%check
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/git-cola.appdata.xml


%files
%license COPYING COPYRIGHT README.md
%{_bindir}/cola
%{_bindir}/git-*
%{_datadir}/applications/git*.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/metainfo/git*.appdata.xml
%{_docdir}/%{name}/
%{_mandir}/man1/git*.1*
%{python3_sitelib}/*


%changelog
* Tue Dec 19 2023 papoteur <papoteur> 4.0.4-3.mga10
+ Revision: 2019193
- Mass Rebuild - Python 3.12

* Mon Mar 20 2023 papoteur <papoteur> 4.0.4-2.mga9
+ Revision: 1949830
- replace Requires qtwebkit by qtwebengine
- remove Requires Pyside2, there is already python-qt5, not both are required

* Sun Dec 11 2022 ghibo <ghibo> 4.0.4-1.mga9
+ Revision: 1920567
- More BuildRequires for install-doc target.
- Use make for install-doc and install-html.
- More verbose installation
- Compact desktop-file-validate
- Fix comment about NO_VENDOR_LIBS
- Remove building option NO_VENDOR_LIBS=1 as no longer required since release 4.0.0.
- Add more desktop-file-validate.
- Update to release 4.0.4.
- Fix Source0 path (thanks wally).
- %%pyprojectification.
- Fix files list.

* Wed Apr 06 2022 umeabot <umeabot> 3.11.0-3.mga9
+ Revision: 1845997
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 3.11.0-2.mga9
+ Revision: 1782861
- BR python3.9dist() -> python3dist(): do NOT hardcode py version!!!
- Rebuild for python-3.10

* Mon Jan 24 2022 mrambo3501 <mrambo3501> 3.11.0-1.mga9
+ Revision: 1769652
- version 3.11.0
- BR python3.9dist(importlib-metadata)
- convert global _python_bytecompile_extra to _py_byte_compile

* Sat Mar 27 2021 tv <tv> 3.9-2.mga9
+ Revision: 1710867
- rebuild for python 3.9

* Thu Mar 11 2021 daviddavid <daviddavid> 3.9-1.mga9
+ Revision: 1701265
- new version: 3.9

* Wed Nov 25 2020 shlomif <shlomif> 3.8-1.mga8
+ Revision: 1649129
- New version 3.8
+ cheeseeboi <cheeseeboi>
- Use %%make_install instead of %%{make_install}

* Wed Jun 03 2020 cheeseeboi <cheeseeboi> 3.7-1.mga8
+ Revision: 1590052
- Updated to version 3.7
- Replaced some macros in make

* Tue Feb 18 2020 daviddavid <daviddavid> 3.6-2.mga8
+ Revision: 1539974
- switch to PyQt5 (upstream default choice)
- add missing BR on Pyside2
- use system qtpy module instead of a bundled copy
- relax appdata check validation
- no need to check/validate desktop files (already done in BS process)
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon Dec 09 2019 shlomif <shlomif> 3.6-1.mga8
+ Revision: 1465343
- New version 3.6

* Tue Jul 23 2019 shlomif <shlomif> 3.4-1.mga8
+ Revision: 1423489
- mageiaisation
- from fedora


* Fri Jun 28 2019 Oliver Haessler <oliver@redhat.com> - 3.4-1
- Update to 3.4

* Mon Feb 04 2019 Oliver Haessler <oliver@redhat.com> - 3.3-1
- Update to 3.3

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jan 08 2019 Oliver Haessler <oliver@redhat.com> - 3.2-1
- Update to 3.2

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.10-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 2.10-5
- Rebuilt for Python 3.7

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Jan 14 2017 Oliver Haessler <oliver@redhat.com> - 2.10-1
- Update to 2.10

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.9.1-2
- Rebuild for Python 3.6

* Thu Nov 24 2016 Oliver Haessler <oliver@redhat.com> - 2.9.1-1
- Update to 2.9.1

* Wed Nov 23 2016 Oliver Haessler <oliver@redhat.com> - 2.9-1
- Update to 2.9

* Tue Aug 30 2016 Oliver Haessler <oliver@redhat.com> - 2.8-1
- Update to 2.8

* Mon Aug 01 2016 Oliver Haessler <oliver@redhat.com> - 2.7-1
- Update to 2.7

* Fri May 06 2016 Nikos Roussos <comzeradd@fedoraproject.org> - 2.6-1
- Update to 2.6

* Wed Mar 02 2016 Rex Dieter <rdieter@fedoraproject.org> 2.3-6
- Requires: PyQt4-webkit

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Dec 29 2015 Kevin Kofler <Kevin@tigcc.ticalc.org> - 2.3-4
- Drop obsolete (since 2.0.0) dependency on python*-simplejson (#1294541)

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Fri Sep 18 2015 Richard Hughes <rhughes@redhat.com> - 2.3-2
- Remove no longer required AppData file

* Tue Aug 11 2015 Kevin Kofler <Kevin@tigcc.ticalc.org> - 2.3-1
- Update to 2.3 (#1231812)

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Apr 01 2015 Christopher Meng <rpm@cicku.me> - 2.1.2-1
- Update to 2.1.2

* Thu Mar 26 2015 Richard Hughes <rhughes@redhat.com> - 2.0.8-3
- Add an AppData file for the software center

* Mon Dec 15 2014 Kevin Kofler <Kevin@tigcc.ticalc.org> - 2.0.8-2
- Build against Python 3 on Fedora >= 22

* Fri Dec 12 2014 Kevin Kofler <Kevin@tigcc.ticalc.org> - 2.0.8-1
- Update to 2.0.8 (#1136235, also fixes #1171612)
- Use less hackish GitHub Source0 URL
- Add new icon to file list, icon scriptlets, Requires: hicolor-icon-theme

* Sun Aug 03 2014 Kevin Kofler <Kevin@tigcc.ticalc.org> - 2.0.5-1
- Update to 2.0.5 (#1124151)

* Thu Jun 26 2014 Christopher Meng <rpm@cicku.me> - 2.0.4-1
- Update to 2.0.4

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 31 2014 Kevin Kofler <Kevin@tigcc.ticalc.org> - 2.0.3-1
- Update to 2.0.3 (#1101185)
- Drop BR asciidoc, not used anymore (since 2.0.2)

* Wed Apr 23 2014 Christopher Meng <rpm@cicku.me> - 2.0.2-1
- Update to 2.0.2

* Fri Mar 21 2014 Christopher Meng <rpm@cicku.me> - 2.0.1-1
- Update to 2.0.1

* Wed Feb 26 2014 Christopher Meng <rpm@cicku.me> - 2.0.0-1
- Update to 2.0.0

* Sat Feb 15 2014 Christopher Meng <rpm@cicku.me> - 1.9.4-2
- Remove unneeded dependency.

* Fri Feb 07 2014 Christopher Meng <rpm@cicku.me> - 1.9.4-1
- Update to 1.9.4

* Thu Dec 12 2013 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.9.3-1
- Update to 1.9.3 (#1040157)

* Thu Nov 28 2013 Christopher Meng <rpm@cicku.me> - 1.9.2-1
- Update to 1.9.2 with fix for BZ#1034778.

* Tue Nov 12 2013 Christopher Meng <rpm@cicku.me> - 1.9.1-1
- Update to 1.9.1 with fix for BZ#1028854.

* Wed Sep 25 2013 Christopher Meng <rpm@cicku.me> - 1.8.5-1
- Update to 1.8.5(BZ#1011796) with fix for BZ#886826.

* Thu Sep 05 2013 Christopher Meng <rpm@cicku.me> - 1.8.4-1
- Update to 1.8.4(BZ#1003317) with fix for BZ#1001200/BZ#1001200.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 30 2013 Christopher Meng <rpm@cicku.me> - 1.8.3-1
- Update to 1.8.3.
- Cleanup the spec.

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Dec 13 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.8.1-1
- Update to 1.8.1 (#885442)

* Wed Sep 26 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.8.0-1
- Update to 1.8.0 (#849593)

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue May 08 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.7.7-1
- Update to 1.7.7 (#819165)

* Mon Mar 19 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.7.6-1
- Update to 1.7.6 (#804407)

* Mon Feb 20 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.7.5-1
- Update to 1.7.5 (#789309)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Aug 21 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.4.3.5-1
- Update to 1.4.3.5 (#732249)

* Sat May 21 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.4.3.4-1
- Update to 1.4.3.4 (#706588)

* Sat Apr 23 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.4.3.3-1
- Update to 1.4.3.3 (#699123)

* Thu Apr 14 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.4.3.2-1
- Update to 1.4.3.2 (#696563, #694806)

* Sun Mar 06 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.4.3.1-1
- Update to 1.4.3.1 (#682518)
- Drop upstreamed translations patch

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan 03 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.4.3-1
- Update to 1.4.3, fixes broken Actions widget
- Drop docpath patch, fixed upstream
- Drop obsolete conditional for Fedora <= 11
- Fix installation of translations

* Fri Jul 30 2010 Thomas Spura <tomspur@fedoraproject.org> - 1.4.1.2-5
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.4.1.2-4
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sat Mar 13 2010 Ben Boeckel <MathStuf@gmail.com> - 1.4.1.2-3
- Backport patch for documentation path

* Mon Jan 25 2010 Ben Boeckel <MathStuf@gmail.com> - 1.4.1.2-2
- Fix %%files list

* Sun Jan 24 2010 Ben Boeckel <MathStuf@gmail.com> - 1.4.1.2-1
- Update to 1.4.1.2

* Thu Dec 10 2009 Ben Boeckel <MathStuf@gmail.com> - 1.4.1-1
- Update to 1.4.1

* Tue Nov 17 2009 Ben Boeckel <MathStuf@gmail.com> 1.4.0.5-1
- Update to 1.4.0.5

* Mon Nov 02 2009 Ben Boeckel <MathStuf@gmail.com> 1.4.0.1-1
- Update to 1.4.0.1
- Add patch to not ship simplejson

* Sat Oct 24 2009 Ben Boeckel <MathStuf@gmail.com> 1.4.0-1
- Update to 1.4.0

* Fri Aug 28 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.9.14-1
- Update to 1.3.9.14

* Wed Jul 29 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.8-3
- Try build again for mass rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun May 24 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.8-1
- Update to 1.3.8
- Fix changelog usage of %%
- BR and R on git instead of git-core
- Add conditionals on git-difftool

* Mon Mar 23 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.6-1
- Update to 1.3.6

* Mon Mar 16 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.5.42-1
- Update to 1.3.5.42

* Sat Feb 28 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.5.28-1
- Added %%post and %%postun
- Use desktop-file-install

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Feb 9 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.5-4
- Added missing Requires on PyQt4

* Thu Feb 5 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.5-3
- Added patch for shebang line removal

* Thu Feb 5 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.5-2
- Add missing BRs

* Sun Feb 1 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.5-1
- Update for 1.3.5

* Thu Jan 8 2009 Ben Boeckel <MathStuf@gmail.com> 1.3.4.4-1
- Initial package
